<?php
namespace Ak\Wp\Core;

use MO;
use Laminas\Cache\Storage\StorageInterface;

/**
 * Učitava prijevode.
 *
 * @package Ak\Wp\Core
 */
final class TranslationLoader
{
    /** @var StorageInterface */
    private $cache;

    /**
     * Konstruktor.
     *
     * @param StorageInterface $cache
     */
    public function __construct(StorageInterface $cache)
    {
        $this->cache = $cache;
    }

    /**
     * Učitava .mo datoteku za datu domenu.
     *
     * @param string $domain
     * @param string $mofile
     */
    public function load_textdomain(string $domain, string $mofile): void
    {
        if (!is_readable($mofile)) {
            return;
        }

        global $l10n;

        $cacheKey = md5($mofile);
        $mo = null;
        $mtime = filemtime($mofile);

        if ($this->cache->hasItem($cacheKey)) {
            $cached = $this->cache->getItem($cacheKey);

            if ($cached['time'] > $mtime) {
                $mo = $cached['mo'];
            }
        }

        if (!isset($mo)) {
            $mo = new MO();

            if (!$mo->import_from_file($mofile)) {
                return;
            }

            $this->cache->setItem($cacheKey, [
                'mo' => $mo,
                'time' => time(),
            ]);
        }

        if (isset($l10n[$domain])) {
            $mo->merge_with($l10n[$domain]);
        }

        $l10n[$domain] = &$mo;
    }

    /**
     * Pokušava .mo datoteke učitati iz keša prvo.
     *
     * @param bool $overriden
     * @param string $domain
     * @param string $mofile
     *
     * @return bool
     */
    public function override_load_textdomain(/** @noinspection PhpUnusedParameterInspection */ bool $overriden, string $domain, string $mofile): bool
    {
        $this->load_textdomain($domain, $mofile);
        return true;
    }
}
