<?php
namespace Ak\Wp\Init;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;

/**
 * Class DefaultFilters
 *
 * @package Ak\Wp\Init
 */
final class DefaultHooks implements MiddlewareInterface
{
    /**
     * Process an incoming server request and return a response, optionally delegating
     * response creation to a handler.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        // Default authentication filters
        add_filter('authenticate', 'wp_authenticate_username_password', 20, 3);
        add_filter('authenticate', 'wp_authenticate_email_password', 20, 3);
        add_filter('authenticate', 'wp_authenticate_spam_check', 99);
        add_filter('determine_current_user', 'wp_validate_auth_cookie');
        add_filter('determine_current_user', 'wp_validate_logged_in_cookie', 20);

        add_action('wp_default_scripts', 'wp_default_scripts');
        add_action('wp_default_styles', 'wp_default_styles');

        add_action('wp_head', '_wp_render_title_tag', 1);
        add_action('wp_head', 'wp_enqueue_scripts', 1);
        add_action('wp_head', 'wp_print_styles', 8);
        add_action('wp_head', 'wp_print_head_scripts', 9);

        add_action('wp_footer', 'wp_print_footer_scripts', 20);
        add_action('wp_print_footer_scripts', '_wp_footer_scripts');

        add_action('template_redirect', '_wp_admin_bar_init', 0);
        add_action('wp_footer', 'wp_admin_bar_render', 1000);

        add_action('wp_enqueue_scripts', function() {
            $scripts = wp_scripts();

            $scripts->add_data('jquery', 'group', 1);
            $scripts->add_data('jquery-core', 'group', 1);
            $scripts->add_data('jquery-migrate', 'group', 1);

            wp_dequeue_style('flatsome-style');
        }, PHP_INT_MAX);

        return $handler->handle($request);
    }
}