<?php
namespace Ak\Wp\Init;

use Ak\Wp\Plugin\PluginLoader;
use Psr\Container\ContainerInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;

/**
 * Class Plugin
 *
 * @package Ak\Wp\Init
 */
final class Plugin implements MiddlewareInterface
{
    /**
     * Process an incoming server request and return a response, optionally delegating
     * response creation to a handler.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        // Create common globals.
        require ABSPATH . WPINC . '/vars.php';

        // Define constants that rely on the API to obtain the default value.
        // Define must-use plugin directory constants, which may be overridden in the sunrise.php drop-in.
        wp_plugin_directory_constants();

        $GLOBALS['wp_plugin_paths'] = array();

        /**
         * Fires once all must-use and network-activated plugins have loaded.
         *
         * @since 2.8.0
         */
        do_action('muplugins_loaded');

        // Define constants after multisite is loaded.
        wp_cookie_constants();

        /** @var ContainerInterface $container */
        $container = $request->getAttribute('container');
        /** @var PluginLoader $pluginLoader */
        $pluginLoader = $container->get('wp.plugin_loader');
        $pluginLoader->register();

        // Load active plugins.
        foreach (wp_get_active_and_valid_plugins() as $plugin) {
            wp_register_plugin_realpath( $plugin );
            /** @noinspection PhpIncludeInspection */
            include_once $plugin;
        }

        require_once ABSPATH . '/wp-includes/pluggable.php';

        /**
         * Fires once activated plugins have loaded.
         *
         * Pluggable functions are also available at this point in the loading order.
         *
         * @since 1.5.0
         */
        do_action('plugins_loaded');

        return $handler->handle($request);
    }
}