<?php
namespace Ak\Wp\Service;

use Ak\Wp\ConfigProvider;
use Ak\Wp\Exception;
use Laminas\ConfigAggregator\ArrayProvider;
use Laminas\ConfigAggregator\ConfigAggregator;
use Laminas\ConfigAggregator\PhpFileProvider;

/**
 * Stvara konfiguracijski array.
 *
 * @package Ak\Wp\Service
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/wp
 */
final class ConfigFactory
{
    /**
     * Putanja do varijabilnog spremišta konfiguracije.
     *
     * @var string
     */
    private $varPath;

    /**
     * Konstruktor.
     *
     * @param string $varPath
     */
    public function __construct(string $varPath = null)
    {
        $this->varPath = $varPath;
    }

    /**
     * Vraća sakupljeni konfiguracijski array.
     *
     * @param string $autoloadPath
     * @param bool $isDevelopment
     * @return array
     */
    public function __invoke(string $autoloadPath, bool $isDevelopment = false): array
    {
        if (!$isDevelopment) {
            $cacheConfigFile = $this->getVarPath() . '/merged.php';
        }

        return (new ConfigAggregator([
            ConfigProvider::class,
            new PhpFileProvider($autoloadPath . '/{{,*.}global,{,*.}local}.php'),

            new ArrayProvider([
                ConfigAggregator::ENABLE_CACHE => !$isDevelopment,
            ]),
        ], $cacheConfigFile ?? null))->getMergedConfig();
    }

    /**
     * Vraća putanju do spremišta konfiguracije.
     *
     * @return string
     */
    private function getVarPath(): string
    {
        if (file_exists($this->varPath) && !is_dir($this->varPath)) {
            throw new Exception\InvalidArgumentException(sprintf(
                "Putanja '%s' postoji, ali nije direktorij.", $this->varPath
            ));
        }

        if (!file_exists($this->varPath)) {
            mkdir($this->varPath, 0777, true);
        }

        return $this->varPath;
    }
}
