<?php
namespace Ak\Wp;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Laminas\Stratigility\MiddlewarePipe;
use Laminas\Stratigility\MiddlewarePipeInterface;
use function Laminas\Stratigility\path;

/**
 * Class WordPress
 *
 * @package Ak\Wp
 */
final class WordPress implements MiddlewarePipeInterface
{
    /** @var MiddlewarePipe */
    private $pipe;

    /**
     * WordPress constructor.
     */
    public function __construct()
    {
        $this->pipe = new MiddlewarePipe();

        $this->pipe->pipe(new Init\BaseUrl());
        $this->pipe->pipe(new Init\Cache());
        $this->pipe->pipe(new Init\Includes());
        $this->pipe->pipe(new Init\Database());
        $this->pipe->pipe(new Init\WordPress());
        $this->pipe->pipe(new Init\DefaultHooks());
        $this->pipe->pipe(new Init\L10n());
        $this->pipe->pipe(new Init\Plugin());
        $this->pipe->pipe(new Init\Theme());
        $this->pipe->pipe(new Init\Boot());

        $this->pipe->pipe(path('/install', new Handler\Install()));
        $this->pipe->pipe(path('/', new Handler\Index()));
    }


    /**
     * Process an incoming server request and return a response, optionally delegating
     * response creation to a handler.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        return $this->pipe->process($request, $handler);
    }

    /**
     * @param MiddlewareInterface $middleware
     */
    public function pipe(MiddlewareInterface $middleware): void
    {
        $this->pipe->pipe($middleware);
    }

    /**
     * Handles a request and produces a response.
     *
     * May call other collaborating code to generate the response.
     *
     * @param ServerRequestInterface $request
     * @return ResponseInterface
     */
    public function handle(ServerRequestInterface $request): ResponseInterface
    {
        return $this->pipe->handle($request);
    }
}
