<?php
namespace AkTest\Wp\Service;

use Ak\Wp\Service\ConfigFactory;
use PHPUnit\Framework\TestCase;

/**
 * Class ConfigFactoryTest
 *
 * @package AkTest\Wp\Service
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/wp
 */
class ConfigFactoryTest extends TestCase
{
    const VAR_PATH = __DIR__ . '/var/config';

    protected function setUp()
    {
        parent::setUp();
        $this->deleteVar(__DIR__ . '/var');
    }

    protected function tearDown()
    {
        parent::tearDown();
        $this->deleteVar(__DIR__ . '/var');
    }

    /**
     * @param string $path
     */
    private function deleteVar(string $path = self::VAR_PATH): void
    {
        if (!file_exists($path)) {
            return;
        }

        foreach (scandir($path) as $file) {
            IF (preg_match('/^\.+$/', $file)) continue;

            if (is_dir($path . '/' . $file)) {
                $this->deleteVar($path . '/' . $file);
            } else {
                unlink($path . '/' . $file);
            }
        }

        rmdir($path);
    }

    /**
     * @expectedException \Ak\Wp\Exception\InvalidArgumentException
     */
    public function testWillThrowExceptionForInvalidVarPath()
    {
        $factory = new ConfigFactory(__DIR__ . '/ConfigFactoryTest.php');
        $factory('.');
    }

    public function testWillCreateVarPath()
    {
        $factory = new ConfigFactory(self::VAR_PATH);
        $factory('.');

        $this->assertTrue(file_exists(self::VAR_PATH));
        $this->assertTrue(is_dir(self::VAR_PATH));
    }
}
